"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const globals_1 = require("@jest/globals");
const enums_1 = require("../../enums");
const string_module_1 = require("./string.module");
(0, globals_1.describe)('module/string', () => {
    const module = new string_module_1.ModuleString();
    const { camelCase, lowerKebabCase, lowerSnakeCase, pascalCase, upperKebabCase, upperSnakeCase } = enums_1.enumSnippetName;
    (0, globals_1.test)('toCase', () => {
        (0, globals_1.expect)(module.toCamelCase(lowerKebabCase)).toBe(camelCase);
        (0, globals_1.expect)(module.toLowerKebabCase(lowerKebabCase)).toBe(lowerKebabCase);
        (0, globals_1.expect)(module.toLowerSnakeCase(lowerKebabCase)).toBe(lowerSnakeCase);
        (0, globals_1.expect)(module.toPascalCase(lowerKebabCase)).toBe(pascalCase);
        (0, globals_1.expect)(module.toUpperKebabCase(lowerKebabCase)).toBe(upperKebabCase);
        (0, globals_1.expect)(module.toUpperSnakeCase(lowerKebabCase)).toBe(upperSnakeCase);
    });
    (0, globals_1.test)('isCamelCase', () => {
        (0, globals_1.expect)(module.isCamelCase(camelCase)).toBe(true);
        (0, globals_1.expect)(module.isCamelCase(lowerKebabCase)).toBe(false);
        (0, globals_1.expect)(module.isCamelCase(lowerSnakeCase)).toBe(false);
        (0, globals_1.expect)(module.isCamelCase(pascalCase)).toBe(false);
        (0, globals_1.expect)(module.isCamelCase(upperKebabCase)).toBe(false);
        (0, globals_1.expect)(module.isCamelCase(upperSnakeCase)).toBe(false);
    });
    (0, globals_1.test)('isLowerKebabCase', () => {
        (0, globals_1.expect)(module.isLowerKebabCase(camelCase)).toBe(false);
        (0, globals_1.expect)(module.isLowerKebabCase(lowerKebabCase)).toBe(true);
        (0, globals_1.expect)(module.isLowerKebabCase(lowerSnakeCase)).toBe(false);
        (0, globals_1.expect)(module.isLowerKebabCase(pascalCase)).toBe(false);
        (0, globals_1.expect)(module.isLowerKebabCase(upperKebabCase)).toBe(false);
        (0, globals_1.expect)(module.isLowerKebabCase(upperSnakeCase)).toBe(false);
    });
    (0, globals_1.test)('isLowerSnakeCase', () => {
        (0, globals_1.expect)(module.isLowerSnakeCase(camelCase)).toBe(false);
        (0, globals_1.expect)(module.isLowerSnakeCase(lowerKebabCase)).toBe(false);
        (0, globals_1.expect)(module.isLowerSnakeCase(lowerSnakeCase)).toBe(true);
        (0, globals_1.expect)(module.isLowerSnakeCase(pascalCase)).toBe(false);
        (0, globals_1.expect)(module.isLowerSnakeCase(upperKebabCase)).toBe(false);
        (0, globals_1.expect)(module.isLowerSnakeCase(upperSnakeCase)).toBe(false);
    });
    (0, globals_1.test)('isPascalCase', () => {
        (0, globals_1.expect)(module.isPascalCase(camelCase)).toBe(false);
        (0, globals_1.expect)(module.isPascalCase(lowerKebabCase)).toBe(false);
        (0, globals_1.expect)(module.isPascalCase(lowerSnakeCase)).toBe(false);
        (0, globals_1.expect)(module.isPascalCase(pascalCase)).toBe(true);
        (0, globals_1.expect)(module.isPascalCase(upperKebabCase)).toBe(false);
        (0, globals_1.expect)(module.isPascalCase(upperSnakeCase)).toBe(false);
    });
    (0, globals_1.test)('isUpperKebabCase', () => {
        (0, globals_1.expect)(module.isUpperKebabCase(camelCase)).toBe(false);
        (0, globals_1.expect)(module.isUpperKebabCase(lowerKebabCase)).toBe(false);
        (0, globals_1.expect)(module.isUpperKebabCase(lowerSnakeCase)).toBe(false);
        (0, globals_1.expect)(module.isUpperKebabCase(pascalCase)).toBe(false);
        (0, globals_1.expect)(module.isUpperKebabCase(upperKebabCase)).toBe(true);
        (0, globals_1.expect)(module.isUpperKebabCase(upperSnakeCase)).toBe(false);
    });
    (0, globals_1.test)('isUpperSnakeCase', () => {
        (0, globals_1.expect)(module.isUpperSnakeCase(camelCase)).toBe(false);
        (0, globals_1.expect)(module.isUpperSnakeCase(lowerKebabCase)).toBe(false);
        (0, globals_1.expect)(module.isUpperSnakeCase(lowerSnakeCase)).toBe(false);
        (0, globals_1.expect)(module.isUpperSnakeCase(pascalCase)).toBe(false);
        (0, globals_1.expect)(module.isUpperSnakeCase(upperKebabCase)).toBe(false);
        (0, globals_1.expect)(module.isUpperSnakeCase(upperSnakeCase)).toBe(true);
    });
    (0, globals_1.test)('snapshot', () => {
        (0, globals_1.expect)(module.toCamelCase(lowerKebabCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.toLowerKebabCase(lowerKebabCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.toLowerSnakeCase(lowerKebabCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.toPascalCase(lowerKebabCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.toUpperKebabCase(lowerKebabCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.toUpperSnakeCase(lowerKebabCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isCamelCase(camelCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isCamelCase(lowerKebabCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isCamelCase(lowerSnakeCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isCamelCase(pascalCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isCamelCase(upperKebabCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isCamelCase(upperSnakeCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isLowerKebabCase(camelCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isLowerKebabCase(lowerKebabCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isLowerKebabCase(lowerSnakeCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isLowerKebabCase(pascalCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isLowerKebabCase(upperKebabCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isLowerKebabCase(upperSnakeCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isLowerSnakeCase(camelCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isLowerSnakeCase(lowerKebabCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isLowerSnakeCase(lowerSnakeCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isLowerSnakeCase(pascalCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isLowerSnakeCase(upperKebabCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isLowerSnakeCase(upperSnakeCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isPascalCase(camelCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isPascalCase(lowerKebabCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isPascalCase(lowerSnakeCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isPascalCase(pascalCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isPascalCase(upperKebabCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isPascalCase(upperSnakeCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isUpperKebabCase(camelCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isUpperKebabCase(lowerKebabCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isUpperKebabCase(lowerSnakeCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isUpperKebabCase(pascalCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isUpperKebabCase(upperKebabCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isUpperKebabCase(upperSnakeCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isUpperSnakeCase(camelCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isUpperSnakeCase(lowerKebabCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isUpperSnakeCase(lowerSnakeCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isUpperSnakeCase(pascalCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isUpperSnakeCase(upperKebabCase)).toMatchSnapshot();
        (0, globals_1.expect)(module.isUpperSnakeCase(upperSnakeCase)).toMatchSnapshot();
    });
});
